<?php

namespace Drupal\Tests\salesforce_mfw\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;

/**
 * Tests that other block plugins can be enabled, disabled, and removed.
 *
 * @group salesforce_mfw
 */
class BlockOperations extends BrowserTestBase {

  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'salesforce_mfw',
    'block',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $user = $this->createUser([
      'administer blocks',
      'administer site configuration',
    ]);
    $this->drupalPlaceBlock('user_login_block');
    $this->drupalLogin($user);
  }

  /**
   * Tests disabling, enabling, and removing a user login block.
   */
  public function testBlockDisableAndEnable() {
    $this->drupalGet('admin/structure/block/');
    $this->getSession()->getPage()->clickLink('Disable');
    $this->assertSession()->pageTextContains('The block settings have been updated.');
    $this->getSession()->getPage()->clickLink('Enable');
    $this->assertSession()->pageTextContains('The block settings have been updated.');
    $this->getSession()->getPage()->clickLink('Remove');
    $this->getSession()->getPage()->pressButton('Remove');
    $this->assertSession()->pageTextNotContains('Configure');
  }

}
